<?php
namespace AIOSEO\Plugin\Extend\Admin;

use AIOSEO\Plugin\Common\Admin as CommonAdmin;

class Admin extends CommonAdmin\Admin {

	/**
	 * Class constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', [ $this, 'registerLocation' ] );
		add_action( 'init', [ $this, 'registerLocationCategory' ] );
	}

	/**
	 * Registers the Location post type.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function registerLocation() {
		register_post_type( 'aioseo-location', [
			'labels'       => [
				'name'          => __( 'Locations', 'all-in-one-seo-pack' ),
				'singular_name' => __( 'Location', 'all-in-one-seo-pack' )
			],
			'description'  => sprintf(
				// Translators: 1 - The plugin name ("All in One SEO").
				__( '%1$s uses these locations to generate Local Business schema markup.', 'all-in-one-seo-pack' ),
				AIOSEO_PLUGIN_NAME
			),
			'public'       => true,
			'rewrite'      => [
				'slug' => 'location',
			],
			'pages'        => false,
			'menu_icon'    => 'dashicons-location',
			'taxonomies'   => [ 'aioseo-location-category' ],
			'show_in_rest' => true
			// @TODO: [V4+] Do we need to add a capability here?
		]);
	}

	/**
	 * Registers the Location Category taxonomy.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function registerLocationCategory() {
		register_taxonomy( 'aioseo-location-category', 'aioseo-location', [
			'labels'  => [
				'name'          => __( 'Location Categories', 'all-in-one-seo-pack' ),
				'singular_name' => __( 'Location Category', 'all-in-one-seo-pack' )
			],
			'public'  => true,
			'rewrite' => [
				'slug' => 'locations',
			]
			// @TODO: [V4+] Do we need to add a capability here?
		] );
	}
}